Python Script Bootstraps
========================

The ``sandal`` library is a collection of common things that Michael Ekstrand
uses in his experiment scripts and similar code, particularly in experiments
using LensKit_.  This package is to make it easy to install that code by just
depending on it from PyPI.

.. _LensKit: https://lenskit.org

.. toctree::
    :maxdepth: 2

    cli
    notebook
